==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/es_MX.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Liga pública",
    "Photos" : "Fotos",
    "On This Day" : "En este día",
    "Your memories under your control" : "Tus recuerdos bajo tu control",
    "All media" : "Todos los medios",
    "Videos" : "Videos",
    "Albums" : "Álbumes",
    "Collaborative albums" : "Álbumes colaborativos",
    "People" : "Personas",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "On this day" : "En este día",
    "Shared with you" : "Compartido con usted",
    "Tags" : "Etiquetas",
    "Places" : "Lugares",
    "Map" : "Mapa",
    "Photos settings" : "Configuración de fotos",
    "Mark selection as favorite" : "Marcar selección como favorita",
    "Add selection to favorites" : "Añadir selección a favoritos",
    "Remove selection from favorites" : "Eliminar selección de favoritos",
    "Name of the album" : "Nombre del álbum",
    "Location of the album" : "Ubicación del álbum",
    "Back" : "Atrás",
    "Add collaborators" : "Añadir colaboradores",
    "Save" : "Guardar",
    "Create album" : "Crear álbum",
    "Add to Album" : "Añadir al álbum",
    "Add selection to album {albumName}" : "Añadir selección al álbum {albumName}",
    "Shared by" : "Compartido por",
    "Create a new album." : "Crear un nuevo álbum.",
    "Create new album" : "Crear nuevo álbum",
    "New album" : "Nuevo álbum",
    "_%n item_::_%n photos and videos_" : ["%n elemento","%n fotos y videos","%n fotos y videos"],
    "Failed to fetch collaborators list." : "No se pudo obtener la lista de colaboradores.",
    "Failed to update album." : "No se pudo actualizar el álbum.",
    "Add people or groups who can edit your album" : "Añadir personas o grupos que puedan editar su álbum",
    "Search people or groups" : "Buscar personas o grupos",
    "No recommendations. Start typing." : "Sin recomendaciones. Empiece a escribir.",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Eliminar {collaboratorLabel} de la lista de colaboradores",
    "Copy the public link" : "Copiar el enlace público",
    "Public link copied!" : "¡Enlace público copiado!",
    "Copy public link" : "Copiar enlace público",
    "Delete the public link" : "Eliminar el enlace público",
    "Create public link share" : "Crear un enlace público compartido",
    "Share via public link" : "Compartir mediante enlace público",
    "This collection does not exist" : "Esta colección no existe",
    "An error occurred" : "Ha ocurrido un error",
    "No picture for this day" : "No hay fotos de este día",
    "Picture taken on this day will show up here." : "Las fotos tomadas este día aparecerán aquí,",
    "More photos from this day" : "Más fotos de este día",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto sin asignar","%n fotos sin asignar","%n fotos sin asignar"],
    "Favorite" : "Marcar como favorito",
    "Favorite image, open the full size \"{name}\" image" : "Imagen favorita, abrir la imagen \"{name}\" a tamaño completo",
    "Open the full size \"{name}\" image" : "Abrir Imagen \"{name}\" en tamaño completo",
    "Select image {imageName}" : "Seleccionar imagen {imageName}",
    "Open the \"{name}\" folder" : "Abrir la carpeta \"{name}\"",
    "Back to {folder}" : "Regresar a {folder}",
    "Go back" : "Regresar",
    "Share this folder" : "Compartir esta carpeta",
    "Dates" : "Fechas",
    "Jump to specific date in list" : "Saltar a una fecha específica en la lista",
    "Jump to {date}" : "Saltar a {date}",
    "Add to {destination}" : "Añadir a {destination}",
    "There are no photos or videos yet!" : "¡Aún no hay fotos ni videos!",
    "_{years} year ago_::_{years} years ago_" : ["Hace {years} año","Hace {years} años","Hace {years} años"],
    "Enable squared photos view" : "Habilitar la vista de fotos cuadradas",
    "Delete source directory" : "Eliminar el directorio fuente",
    "Select a source folder for your media" : "Elegir una carpeta fuente para sus medios",
    "All folders" : "Todas las carpetas",
    "Add a Photos source for the timelines" : "Añadir una fuente de fotos para las líneas de tiempo",
    "Add folder" : "Agregar carpeta",
    "Select the default upload location for your media" : "Seleccionar la ubicación predeterminada para los medios",
    "Home" : "Inicio",
    "Choose default Photos upload and Albums location" : "Seleccionar la ubicación predeterminada de carga de fotos y álbumes",
    "Choose a different folder" : "Elegir una carpeta diferente",
    "View" : "Ver",
    "Media folders" : "Carpetas de medios",
    "Choose the folders from where photos and videos are shown." : "Elegir las carpetas de donde se muestren las fotos y videos.",
    "Upload folder" : "Cargar carpeta",
    "Choose the folder where photos and albums are uploaded to." : "Elegir la carpeta donde se carguen las fotos y videos.",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Unselect all" : "Desmarcar todo",
    "Add photos to this album" : "Añadir fotos a este álbum",
    "Manage collaborators for this album" : "Administrar los colaboradores para este álbum",
    "Open actions menu" : "Abrir el menú de acciones",
    "Edit album details" : "Editar los detalles del álbum",
    "Download all files in album" : "Descargar todos los archivos del álbum",
    "Delete album" : "Eliminar álbum",
    "Download selected files" : "Descargar los archivos seleccionados",
    "Remove selection from album" : "Eliminar selección del álbum",
    "This album does not have any photos or videos yet!" : "¡Este álbum aún no tiene fotos ni videos!",
    "Add photos to {albumName}" : "Añadir fotos a {albumName}",
    "Manage collaborators" : "Administrar colaboradores",
    "Save collaborators for this album." : "Guardar los colaboradores para este álbum.",
    "Cover photo for album {albumName}" : "Foto de portada para el álbum {albumName}",
    "There is no album yet!" : "¡Aún no hay álbumes!",
    "This person could not be found" : "No se pudo encontrar a esta persona",
    "Rename person" : "Renombrar persona",
    "Merge with different person" : "Mezclar con una persona diferente",
    "Download selected photos" : "Descargar las fotos seleccionadas",
    "Remove from favorites" : "Eliminar de favoritos",
    "Remove person" : "Eliminar persona",
    "Name of this person" : "Nombre de esta persona",
    "Save." : "Guardar.",
    "Merge person" : "Mezclar persona",
    "Move to different person" : "Mover a otra persona",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover foto a otra persona","Mover fotos a otra persona","Mover fotos a otra persona"],
    "_Remove photo from person_::_Remove photos from person_" : ["Eliminar la foto de la persona","Eliminar fotos de la persona","Eliminar fotos de la persona"],
    "This might take some time depending on the size of your photo library." : "Esto podría tomar algún tiempo dependiendo del tamaño de su biblioteca de fotos.",
    "Recognized people will show up here" : "Aquí aparecerán las personas reconocidas",
    "This folder does not exist" : "Esta carpeta no existe",
    "Loading folders …" : "Cargando carpetas ...",
    "No photos in here" : "No hay fotos aquí",
    "Taken on {date} at {time}" : "Tomada el {date} a las {time}",
    "This place does not have any photos or videos yet!" : "¡Este lugar aún no tiene fotos ni videos!",
    "Add photos to this place" : "Añadir fotos a este lugar",
    "Cover photo for place {placeName}" : "Foto de portada para el lugar {placeName}",
    "There is no place yet!" : "¡Aún no hay ningún lugar!",
    "Cover photo for shared album {albumName}." : "Foto de portada para el álbum compartido {albumName}.",
    "Back to tags overview" : "Volver a la vista general de etiquetas",
    "No photos with this tag yet" : "Aún no hay fotos con esta etiqueta",
    "No tags yet" : "Aún no hay etiquetas",
    "Photos with tags will show up here" : "Las fotos con etiquetas se mostrarán aquí",
    "Popular tags" : "Etiquetas populares",
    "All tags" : "Todas las etiquetas",
    "Add to album" : "Añadir al álbum",
    "Delete selection" : "Borrar selección",
    "No photos or videos in here" : "No hay fotos ni videos aquí",
    "Unassigned faces" : "Caras sin asignar",
    "_%n photos_::_%n photos_" : ["%n fotos","%n fotos","%n fotos"],
    "Failed to fetch collection." : "No se pudo obtener la colección.",
    "Failed to fetch collections list." : "No se pudo obtener la lista de colecciones.",
    "Failed to fetch faces list." : "No se pudo obtener la lista de caras.",
    "All your media" : "Todos los medios",
    "Album {title}" : "Álbum {title}",
    "Shared Albums" : "Álbumes compartidos",
    "Shared album {title}" : "Álbum compartido {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos con etiquetas",
    "Tagged photo {title}" : "Foto etiquetada {title}",
    "{title}'s face" : "Cara de {title}",
    "{startDate} to {endDate}" : "{startDate} a {endDate}",
    "Details" : "Detalles",
    "Failed to rename {oldName} to {faceName}." : "No se pudo renombrar {oldName} a {faceName}.",
    "Failed to delete {faceName}." : "No se pudo borrar {faceName}.",
    "Failed to delete {fileId}." : "No se pudo borrar {fileId}.",
    "Failed to delete {fileName}." : "No se pudo eliminar {fileName}.",
    "Failed to set favorite state for {fileId}." : "No se pudo establecer el estado de favorito para {fileId}.",
    "Failed to set favorite state for {fileName}." : "No se pudo establecer el estado de favorito para {fileName}.",
    "Could not load photos folder" : "No se pudo cargar la carpeta de fotos",
    "One of the source folders does not exists" : "Una de las carpetas fuente no existe",
    "Add" : "Agregar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/es_MX.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Liga pública",
    "Photos" : "Fotos",
    "On This Day" : "En este día",
    "Your memories under your control" : "Tus recuerdos bajo tu control",
    "All media" : "Todos los medios",
    "Videos" : "Videos",
    "Albums" : "Álbumes",
    "Collaborative albums" : "Álbumes colaborativos",
    "People" : "Personas",
    "Folders" : "Carpetas",
    "Favorites" : "Favoritos",
    "On this day" : "En este día",
    "Shared with you" : "Compartido con usted",
    "Tags" : "Etiquetas",
    "Places" : "Lugares",
    "Map" : "Mapa",
    "Photos settings" : "Configuración de fotos",
    "Mark selection as favorite" : "Marcar selección como favorita",
    "Add selection to favorites" : "Añadir selección a favoritos",
    "Remove selection from favorites" : "Eliminar selección de favoritos",
    "This name is already in use." : "Este nombre ya está en uso.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" no está permitido en el nombre de archivo.",
    "Invalid filename." : "Nombre de archivo inválido",
    "Name of the album" : "Nombre del álbum",
    "Location of the album" : "Ubicación del álbum",
    "Back" : "Atrás",
    "Add collaborators" : "Añadir colaboradores",
    "Save" : "Guardar",
    "Create album" : "Crear álbum",
    "Add to Album" : "Añadir al álbum",
    "Add selection to album {albumName}" : "Añadir selección al álbum {albumName}",
    "Shared by" : "Compartido por",
    "Create a new album." : "Crear un nuevo álbum.",
    "Create new album" : "Crear nuevo álbum",
    "New album" : "Nuevo álbum",
    "_%n item_::_%n photos and videos_" : ["%n elemento","%n fotos y videos","%n fotos y videos"],
    "Failed to fetch collaborators list." : "No se pudo obtener la lista de colaboradores.",
    "Failed to update album." : "No se pudo actualizar el álbum.",
    "Add people or groups who can edit your album" : "Añadir personas o grupos que puedan editar su álbum",
    "Search people or groups" : "Buscar personas o grupos",
    "No recommendations. Start typing." : "Sin recomendaciones. Empiece a escribir.",
    "Copy the public link" : "Copiar el enlace público",
    "Public link copied!" : "¡Enlace público copiado!",
    "Copy public link" : "Copiar enlace público",
    "Delete the public link" : "Eliminar el enlace público",
    "Create public link share" : "Crear un enlace público compartido",
    "Share via public link" : "Compartir mediante enlace público",
    "This collection does not exist" : "Esta colección no existe",
    "An error occurred" : "Ha ocurrido un error",
    "No picture for this day" : "No hay fotos de este día",
    "Picture taken on this day will show up here." : "Las fotos tomadas este día aparecerán aquí,",
    "More photos from this day" : "Más fotos de este día",
    "_%n photos_::_%n photos_" : ["%n fotos","%n fotos","%n fotos"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto sin asignar","%n fotos sin asignar","%n fotos sin asignar"],
    "Favorite" : "Marcar como favorito",
    "Favorite image, open the full size \"{name}\" image" : "Imagen favorita, abrir la imagen \"{name}\" a tamaño completo",
    "Open the full size \"{name}\" image" : "Abrir Imagen \"{name}\" en tamaño completo",
    "Select image {imageName}" : "Seleccionar imagen {imageName}",
    "Open the \"{name}\" folder" : "Abrir la carpeta \"{name}\"",
    "Go back" : "Regresar",
    "Dates" : "Fechas",
    "Jump to specific date in list" : "Saltar a una fecha específica en la lista",
    "Jump to {date}" : "Saltar a {date}",
    "Add to {destination}" : "Añadir a {destination}",
    "There are no photos or videos yet!" : "¡Aún no hay fotos ni videos!",
    "_{years} year ago_::_{years} years ago_" : ["Hace {years} año","Hace {years} años","Hace {years} años"],
    "Delete source directory" : "Eliminar el directorio fuente",
    "Select a source folder for your media" : "Elegir una carpeta fuente para sus medios",
    "Media folders" : "Carpetas de medios",
    "Choose the folders from where photos and videos are shown." : "Elegir las carpetas de donde se muestren las fotos y videos.",
    "All folders" : "Todas las carpetas",
    "Add a Photos source for the timelines" : "Añadir una fuente de fotos para las líneas de tiempo",
    "Add folder" : "Agregar carpeta",
    "Home" : "Inicio",
    "Select the default upload location for your media" : "Seleccionar la ubicación predeterminada para los medios",
    "Upload folder" : "Cargar carpeta",
    "General" : "General",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Unselect all" : "Desmarcar todo",
    "Add photos to this album" : "Añadir fotos a este álbum",
    "Manage collaborators for this album" : "Administrar los colaboradores para este álbum",
    "Open actions menu" : "Abrir el menú de acciones",
    "Edit album details" : "Editar los detalles del álbum",
    "Download all files in album" : "Descargar todos los archivos del álbum",
    "Delete album" : "Eliminar álbum",
    "Download selected files" : "Descargar los archivos seleccionados",
    "Remove selection from album" : "Eliminar selección del álbum",
    "This album does not have any photos or videos yet!" : "¡Este álbum aún no tiene fotos ni videos!",
    "Add photos to {albumName}" : "Añadir fotos a {albumName}",
    "Manage collaborators" : "Administrar colaboradores",
    "Save collaborators for this album." : "Guardar los colaboradores para este álbum.",
    "Cover photo for album {albumName}" : "Foto de portada para el álbum {albumName}",
    "There is no album yet!" : "¡Aún no hay álbumes!",
    "This person could not be found" : "No se pudo encontrar a esta persona",
    "Rename person" : "Renombrar persona",
    "Merge with different person" : "Mezclar con una persona diferente",
    "Download selected photos" : "Descargar las fotos seleccionadas",
    "Remove from favorites" : "Eliminar de favoritos",
    "Remove person" : "Eliminar persona",
    "Name of this person" : "Nombre de esta persona",
    "Save." : "Guardar.",
    "Merge person" : "Mezclar persona",
    "Move to different person" : "Mover a otra persona",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover foto a otra persona","Mover fotos a otra persona","Mover fotos a otra persona"],
    "_Remove photo from person_::_Remove photos from person_" : ["Eliminar la foto de la persona","Eliminar fotos de la persona","Eliminar fotos de la persona"],
    "This might take some time depending on the size of your photo library." : "Esto podría tomar algún tiempo dependiendo del tamaño de su biblioteca de fotos.",
    "Recognized people will show up here" : "Aquí aparecerán las personas reconocidas",
    "This folder does not exist" : "Esta carpeta no existe",
    "Loading folders…" : "Cargando carpetas…",
    "No photos in here" : "No hay fotos aquí",
    "Taken on {date} at {time}" : "Tomada el {date} a las {time}",
    "This place does not have any photos or videos yet!" : "¡Este lugar aún no tiene fotos ni videos!",
    "Add photos to this place" : "Añadir fotos a este lugar",
    "Cover photo for place {placeName}" : "Foto de portada para el lugar {placeName}",
    "There is no place yet!" : "¡Aún no hay ningún lugar!",
    "Back to tags overview" : "Volver a la vista general de etiquetas",
    "No photos with this tag yet" : "Aún no hay fotos con esta etiqueta",
    "No tags yet" : "Aún no hay etiquetas",
    "Photos with tags will show up here" : "Las fotos con etiquetas se mostrarán aquí",
    "Popular tags" : "Etiquetas populares",
    "All tags" : "Todas las etiquetas",
    "Add to album" : "Añadir al álbum",
    "Delete selection" : "Borrar selección",
    "No photos or videos in here" : "No hay fotos ni videos aquí",
    "Unassigned faces" : "Caras sin asignar",
    "Failed to fetch collection." : "No se pudo obtener la colección.",
    "Failed to fetch collections list." : "No se pudo obtener la lista de colecciones.",
    "Failed to fetch faces list." : "No se pudo obtener la lista de caras.",
    "All your media" : "Todos los medios",
    "Album {title}" : "Álbum {title}",
    "Shared Albums" : "Álbumes compartidos",
    "Shared album {title}" : "Álbum compartido {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos con etiquetas",
    "Tagged photo {title}" : "Foto etiquetada {title}",
    "{title}'s face" : "Cara de {title}",
    "Last week" : "Semana pasada",
    "{startDate} to {endDate}" : "{startDate} a {endDate}",
    "Details" : "Detalles",
    "Cancel" : "Cancel",
    "Confirm" : "Confirmar",
    "Could not load photos folder" : "No se pudo cargar la carpeta de fotos",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Eliminar {collaboratorLabel} de la lista de colaboradores",
    "Back to {folder}" : "Regresar a {folder}",
    "Share this folder" : "Compartir esta carpeta",
    "Enable squared photos view" : "Habilitar la vista de fotos cuadradas",
    "Choose default Photos upload and Albums location" : "Seleccionar la ubicación predeterminada de carga de fotos y álbumes",
    "Choose a different folder" : "Elegir una carpeta diferente",
    "View" : "Ver",
    "Choose the folder where photos and albums are uploaded to." : "Elegir la carpeta donde se carguen las fotos y videos.",
    "Loading folders …" : "Cargando carpetas ...",
    "Add" : "Agregar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
